@@ -1,10 +1,8 @@
-/* ============================================================
- *
+/*
  * SPDX-FileCopyrightText: 2007-2011 Kare Sars <kare.sars@iki .fi>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef LABELED_CHECKBOX_H
 #define LABELED_CHECKBOX_H
@@ -39,8 +37,8 @@ public:
      */
     LabeledCheckbox(QWidget *parent, const QString &text);
 
-    LabeledCheckbox(QWidget *parent, KSaneOption *option);
-    ~LabeledCheckbox();
+    LabeledCheckbox(QWidget *parent, KSaneCore::Option *option);
+    ~LabeledCheckbox() override;
     void setChecked(bool);
     bool isChecked();
 
@@ -49,10 +47,10 @@ Q_SIGNALS:
 
 public Q_SLOTS:
     void setValue(const QVariant &value);
-    
+
 protected:
     void initCheckBox(const QString &name);
-    
+
 private:
 
     QCheckBox *chbx;
